@@ -13,14 +13,14 @@ lazy_static! {
 fn fetch_file_idx19_u32(id: u32) {
     let mut data_provider = FileProvider::from(&*CACHE);
 
-    data_provider.index(19);
-    data_provider.archive(&(id >> 8));
+    data_provider.index(0);
+    data_provider.archive(&id);
 
-    let _ = data_provider.request(&(id & 0xff));
+    let _ = data_provider.request(&0);
 }
 
 fn criterion_benchmark(c: &mut Criterion) {
-    c.bench_function("file_fetch_idx19_u32", |b| b.iter(|| fetch_file_idx19_u32(black_box(15000))));
+    c.bench_function("file_fetch_idx19_u32", |b| b.iter(|| fetch_file_idx19_u32(black_box(1366))));
 }
 
 criterion_group!(benches, criterion_benchmark);
