@@ -141,12 +141,7 @@ impl CacheIndex {
         let mut file_buff: [u8; 520] = [0; 520];
         let mut data: [u8;6] = [0; 6];
 
-        if archive_id <= 1 || self.last_archive_id == 0 {
-            let _ = self.file.seek(SeekFrom::Start(6 * archive_id as u64));
-        } else if self.last_archive_id != archive_id - 1 {
-            let seek_offset = 6 * (archive_id as i64 - (self.last_archive_id as i64 + 1));
-            let _ = self.file.seek_relative(seek_offset);
-        }
+        let _ = self.file.seek(SeekFrom::Start(6 * archive_id as u64));
 
         self.last_archive_id = archive_id;
 
@@ -184,7 +179,7 @@ impl CacheIndex {
                 let current_pos = initial_dfile_pos + (data_read_count as i64) + (part as i64 * 8);
 
                 if current_pos != seek_target {
-                    let _ = data_file.seek_relative(520);
+                    let _ = data_file.seek(SeekFrom::Start(seek_target as u64));
                 }
 
                 let mut data_to_read = container_size - data_read_count;
